<?php
namespace Bushelpowered\Api\Payments\V1\Model;
        
class PaymentStandard implements \Bushelpowered\Api\Common\Event\StandardRecord, \Bushelpowered\Api\Common\HasSourceTimestamps, \Bushelpowered\Api\Common\HasTimestamps
{
    /** @var string $tenantId The tenant identifier.*/
    public string $tenantId;
    /** @var string $datasourceId The datasource identifier.*/
    public string $datasourceId;
    /** @var string $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.*/
    public string $integrationId;
    /** @var string $sourceId The source record identifier.*/
    public string $sourceId;
    /** @var null|string $sourceAccountId The source account identifier.*/
    public ?string $sourceAccountId = null;
    /** @var null|string $accountId The account identifier.*/
    public ?string $accountId = null;
    /** @var null|string $accountIntegrationId The account integration identifier.*/
    public ?string $accountIntegrationId = null;
    /** @var null|string $sourceLocationId The source location identifier.*/
    public ?string $sourceLocationId = null;
    /** @var null|string $locationId The location identifier.*/
    public ?string $locationId = null;
    /** @var null|string $locationIntegrationId The location integration identifier.*/
    public ?string $locationIntegrationId = null;
    /** @var null|string $sourceCommodityId The source commodity identifier.*/
    public ?string $sourceCommodityId = null;
    /** @var null|string $commodityId The commodity identifier.*/
    public ?string $commodityId = null;
    /** @var null|string $commodityIntegrationId The commodity integration identifier.*/
    public ?string $commodityIntegrationId = null;
    /** @var string $entityRevisionId The revision idempotency key.*/
    public string $entityRevisionId;
    /** @var string[]|null $sourceSettlementIds List of settlementIds that are associated with this payment*/
    public ?array $sourceSettlementIds = null;
    /** @var string[]|null $sourceInvoiceIds List of invoiceIds that are associated with this payment*/
    public ?array $sourceInvoiceIds = null;
    /** @var null|string $sourceDisplayId Id of the payment that the user will see*/
    public ?string $sourceDisplayId = null;
    /** @var float $sourcePaymentAmount The amount of the payment*/
    public float $sourcePaymentAmount;
    /** @var string $sourcePaymentType How the payment was made. ex Check or ACH*/
    public string $sourcePaymentType;
    /** @var string $sourceStatus Status of the payment*/
    public string $sourceStatus;
    /** @var null|string $sourcePaymentDate Date the payment was made. If a deferred payment this will be when the payment was deferred to of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourcePaymentDate = null;
    /** @var null|string $sourceCurrency The currency that the payment was made in. ex USD or CAD*/
    public ?string $sourceCurrency = null;
    /** @var null|string $sourceComments Any comments that are associated with this payment*/
    public ?string $sourceComments = null;
    /** @var string $id The bushel id for this record.*/
    public string $id;
    /** @var string $updatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;
    /** @var string $createdAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;
    /** @var null|string $deletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $deletedAt = null;
    /** @var string $sourceCreatedAt Created date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceCreatedAt;
    /** @var string $sourceUpdatedAt Updated date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceUpdatedAt;
    /** @var null|string $sourceDeletedAt Deleted date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceDeletedAt = null;

    /**
     * @param  string  $tenantId The tenant identifier.
     * @param  string  $datasourceId The datasource identifier.
     * @param  string  $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     * @param  string  $sourceId The source record identifier.
     * @param  null|string  $sourceAccountId The source account identifier.
     * @param  null|string  $accountId The account identifier.
     * @param  null|string  $accountIntegrationId The account integration identifier.
     * @param  null|string  $sourceLocationId The source location identifier.
     * @param  null|string  $locationId The location identifier.
     * @param  null|string  $locationIntegrationId The location integration identifier.
     * @param  null|string  $sourceCommodityId The source commodity identifier.
     * @param  null|string  $commodityId The commodity identifier.
     * @param  null|string  $commodityIntegrationId The commodity integration identifier.
     * @param  string  $entityRevisionId The revision idempotency key.
     * @param  string[]|null  $sourceSettlementIds List of settlementIds that are associated with this payment
     * @param  string[]|null  $sourceInvoiceIds List of invoiceIds that are associated with this payment
     * @param  null|string  $sourceDisplayId Id of the payment that the user will see
     * @param  float  $sourcePaymentAmount The amount of the payment
     * @param  string  $sourcePaymentType How the payment was made. ex Check or ACH
     * @param  string  $sourceStatus Status of the payment
     * @param  null|string  $sourcePaymentDate Date the payment was made. If a deferred payment this will be when the payment was deferred to of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceCurrency The currency that the payment was made in. ex USD or CAD
     * @param  null|string  $sourceComments Any comments that are associated with this payment
     * @param  string  $id The bushel id for this record.
     * @param  string  $updatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $createdAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $deletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $sourceCreatedAt Created date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $sourceUpdatedAt Updated date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceDeletedAt Deleted date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $tenantId, string $datasourceId, string $integrationId, string $sourceId, ?string $sourceAccountId, ?string $accountId, ?string $accountIntegrationId, ?string $sourceLocationId, ?string $locationId, ?string $locationIntegrationId, ?string $sourceCommodityId, ?string $commodityId, ?string $commodityIntegrationId, string $entityRevisionId, ?array $sourceSettlementIds, ?array $sourceInvoiceIds, ?string $sourceDisplayId, float $sourcePaymentAmount, string $sourcePaymentType, string $sourceStatus, ?string $sourcePaymentDate, ?string $sourceCurrency, ?string $sourceComments, string $id, string $updatedAt, string $createdAt, ?string $deletedAt, string $sourceCreatedAt, string $sourceUpdatedAt, ?string $sourceDeletedAt)
    {
        $this->tenantId = $tenantId;
        $this->datasourceId = $datasourceId;
        $this->integrationId = $integrationId;
        $this->sourceId = $sourceId;
        $this->sourceAccountId = $sourceAccountId;
        $this->accountId = $accountId;
        $this->accountIntegrationId = $accountIntegrationId;
        $this->sourceLocationId = $sourceLocationId;
        $this->locationId = $locationId;
        $this->locationIntegrationId = $locationIntegrationId;
        $this->sourceCommodityId = $sourceCommodityId;
        $this->commodityId = $commodityId;
        $this->commodityIntegrationId = $commodityIntegrationId;
        $this->entityRevisionId = $entityRevisionId;
        $this->sourceSettlementIds = $sourceSettlementIds;
        $this->sourceInvoiceIds = $sourceInvoiceIds;
        $this->sourceDisplayId = $sourceDisplayId;
        $this->sourcePaymentAmount = $sourcePaymentAmount;
        $this->sourcePaymentType = $sourcePaymentType;
        $this->sourceStatus = $sourceStatus;
        $this->sourcePaymentDate = $sourcePaymentDate;
        $this->sourceCurrency = $sourceCurrency;
        $this->sourceComments = $sourceComments;
        $this->id = $id;
        $this->updatedAt = $updatedAt;
        $this->createdAt = $createdAt;
        $this->deletedAt = $deletedAt;
        $this->sourceCreatedAt = $sourceCreatedAt;
        $this->sourceUpdatedAt = $sourceUpdatedAt;
        $this->sourceDeletedAt = $sourceDeletedAt;
    }
    
    /**
     * @return string The tenant identifier.
     */
    public function getTenantId(): string
    {
        return $this->tenantId;
    }
    /**
     * @return string The datasource identifier.
     */
    public function getDatasourceId(): string
    {
        return $this->datasourceId;
    }
    /**
     * @return string The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     */
    public function getIntegrationId(): string
    {
        return $this->integrationId;
    }
    /**
     * @return string The source record identifier.
     */
    public function getSourceId(): string
    {
        return $this->sourceId;
    }
    /**
     * @return null|string The account identifier.
     */
    public function getAccountId(): ?string
    {
        return $this->accountId;
    }
    /**
     * @return null|string The location identifier.
     */
    public function getLocationId(): ?string
    {
        return $this->locationId;
    }
    /**
     * @return string The bushel id for this record.
     */
    public function getId(): string
    {
        return $this->id;
    }
    /**
     * @return string The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getUpdatedAt(): string
    {
        return $this->updatedAt;
    }
    /**
     * @return string When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
    /**
     * @return null|string The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getDeletedAt(): ?string
    {
        return $this->deletedAt;
    }
    /**
     * @return string Created date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceCreatedAt(): string
    {
        return $this->sourceCreatedAt;
    }
    /**
     * @return string Updated date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceUpdatedAt(): string
    {
        return $this->sourceUpdatedAt;
    }
    /**
     * @return null|string Deleted date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceDeletedAt(): ?string
    {
        return $this->sourceDeletedAt;
    }
}