<?php
namespace Bushelpowered\Api\Platform\User\V1\Model;
        
class StaffUser implements \Bushelpowered\Api\Common\HasTimestamps
{
    /** @var string $id The unique identifier for the staff user. This is expected to match the bushelId (aka Keycloak.user.id)*/
    public string $id;
    /** @var null|string $firstName The first name of the staff user*/
    public ?string $firstName = null;
    /** @var null|string $lastName The last name of the staff user*/
    public ?string $lastName = null;
    /** @var null|string $email The email address of the staff user*/
    public ?string $email = null;
    /** @var \Bushelpowered\Api\Platform\User\V1\Model\StaffUserIdentifier[] $identifiers The list of identifiers associated with the staff user*/
    public array $identifiers;
    /** @var \Bushelpowered\Api\Platform\User\V1\Model\StaffUserTenant[] $staffTenants The list of tenant associations for the staff user. This will be scoped to the given tenant of the request.*/
    public array $staffTenants;
    /** @var string $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;
    /** @var string $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;
    /** @var null|string $deletedAt Deleted date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $deletedAt = null;

    /**
     * @param  string  $id The unique identifier for the staff user. This is expected to match the bushelId (aka Keycloak.user.id)
     * @param  null|string  $firstName The first name of the staff user
     * @param  null|string  $lastName The last name of the staff user
     * @param  null|string  $email The email address of the staff user
     * @param  \Bushelpowered\Api\Platform\User\V1\Model\StaffUserIdentifier[]  $identifiers The list of identifiers associated with the staff user
     * @param  \Bushelpowered\Api\Platform\User\V1\Model\StaffUserTenant[]  $staffTenants The list of tenant associations for the staff user. This will be scoped to the given tenant of the request.
     * @param  string  $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $deletedAt Deleted date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $id, ?string $firstName, ?string $lastName, ?string $email, array $identifiers, array $staffTenants, string $createdAt, string $updatedAt, ?string $deletedAt)
    {
        $this->id = $id;
        $this->firstName = $firstName;
        $this->lastName = $lastName;
        $this->email = $email;
        $this->identifiers = $identifiers;
        $this->staffTenants = $staffTenants;
        $this->createdAt = $createdAt;
        $this->updatedAt = $updatedAt;
        $this->deletedAt = $deletedAt;
    }
    
    /**
     * @return string Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
    /**
     * @return string Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getUpdatedAt(): string
    {
        return $this->updatedAt;
    }
    /**
     * @return null|string Deleted date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getDeletedAt(): ?string
    {
        return $this->deletedAt;
    }
}